/**
 * Copy files.
 * @memberof module:apeman-commons-compiling
 * @function copyFiles
 * @param {string[]} src - Filenames to copy
 * @param {string} dest - Destination file path.
 * @param {object} [options] - Optional settings.
 * @param {function} [callback] - Callback when done.
 */

"use strict";

var async = require('async'),
    argx = require('argx'),
    filecopy = require('filecopy');

/** @lends filecopy */
function copyFiles(src, dest, options, callback) {
    var args = argx(arguments);
    callback = args.pop('function') || argx.noop;
    options = args.pop('object') || {};
    dest = args.pop('string');
    src = args.remain().reduce(function (a, b) {
        return [].concat(a).concat(b);
    }, []);

    if (!dest) {
        callback(new Error('dest is required.'));
        return;
    }

    async.series([
        function (callback) {
            filecopy(src, dest, {
                mkdirp: true
            }, callback);
        }
    ], callback);
}

module.exports = copyFiles;