/**
 * Render a sass mixin.
 * @function renderSassMixin
 * @param {string} mixinName - Name of mixin.
 * @param {string[]} mixinArgs - Args of mixin.
 * @param {string} dest - Destination file path.
 * @param {object} [options] - Optional settings.
 * @param {boolean} [options.scss=false] - Parse as scsss.
 * @param {string} [options.basedir=process.cwd()] - Base directory path.
 * @param {string[]} [options.imports] - Filenames to import.
 */

"use strict";

var util = require('util');

var argx = require('argx'),
    renderSass = require('./render_sass');

/** @lends renderSassMixin */
function renderSassMixin(mixinName, mixinArgs, dest, options, callback) {
    var args = argx(arguments);
    callback = args.pop('function') || argx.noop;
    options = args.pop('object') || {};


    var style = renderSassMixin.style(mixinName, mixinArgs, options.imports || []);

    renderSass(style, dest, {
        includePaths: [
            options.basedir || process.cwd()
        ],
        scss: options.scss,
        log: options.log
    }, callback);
}

renderSassMixin.style = function style(mixinName, mixinArgs, imports) {
    return util.format(
        "%s;@include %s(%s);",
        [].concat(imports).map(function (importing) {
            return util.format("@import '%s'", importing);
        }).join(';'),
        mixinName,
        [].concat(mixinArgs).join(', ')
    );
};

module.exports = renderSassMixin;